pub struct OmittedCounts {
pub elements: u32,
pub memories: u32,
pub knowledge: u32,
pub adapter_facts: u32,
pub recent_events: u32,
}Expand description
Counts of items the builder filtered out to fit the budget.
Lets the planner notice that the view is compressed and decide whether to act on what it sees, request a tier-up, or pivot.
Fields
elements: u32memories: u32knowledge: u32adapter_facts: u32recent_events: u32Trait Implementations
Sourceimpl Clone for OmittedCounts
impl Clone for OmittedCounts
Sourcefn clone(&self) -> OmittedCounts
fn clone(&self) -> OmittedCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OmittedCounts
impl Debug for OmittedCounts
Sourceimpl Default for OmittedCounts
impl Default for OmittedCounts
Sourcefn default() -> OmittedCounts
fn default() -> OmittedCounts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OmittedCounts
impl<'de> Deserialize<'de> for OmittedCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more